Address class

Annotations
  • @freezed

Constructors

Address({@JsonKey.new(name: 'address_line_1') String? line1, @JsonKey.new(name: 'address_line_2') String? line2, @JsonKey.new(name: 'address_line_3') String? line3, String? town, String? county, String? postcode})
factory
Address.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $AddressCopyWith<Address>
no setterinherited
county String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
line1 String?
no setterinherited
line2 String?
no setterinherited
line3 String?
no setterinherited
postcode String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
town String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited