GasMeterPoint class

Annotations
  • @freezed

Constructors

GasMeterPoint({String? mprn, @JsonKey.new(name: 'consumption_standard') int? consumptionStandard, List<Meter>? meters, List<Agreement>? agreements})
factory
GasMeterPoint.fromJson(Map<String, dynamic> json)
factory

Properties

agreements List<Agreement>?
no setterinherited
consumptionStandard int?
no setterinherited
copyWith → $GasMeterPointCopyWith<GasMeterPoint>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
meters List<Meter>?
no setterinherited
mprn String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited