Meter class

Annotations
  • @freezed

Constructors

Meter({@JsonKey.new(name: 'serial_number') String? serialNumber, List<Register>? registers})
factory
Meter.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $MeterCopyWith<Meter>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
registers List<Register>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited