Register class

Annotations
  • @freezed

Constructors

Register({String? identifier, String? rate, @JsonKey.new(name: 'is_settlement_register') bool? isSettlementRegister})
factory
Register.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $RegisterCopyWith<Register>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
identifier String?
no setterinherited
isSettlementRegister bool?
no setterinherited
rate String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited