Property class
- Annotations
-
- @freezed
Constructors
-
Property({int? id, @JsonKey.new(name: 'moved_in_at') DateTime? moveInDate, @JsonKey.new(name: 'moved_out_at') DateTime? moveOutDate, @JsonKey.new(name: 'address_line_1') String? addressLine1, @JsonKey.new(name: 'address_line_2') String? addressLine2, @JsonKey.new(name: 'address_line_3') String? addressLine3, String? town, String? county, String? postcode, @JsonKey.new(name: 'electricity_meter_points') List<
ElectricityMeterPoint> ? electricityMeterPoints, @JsonKey.new(name: 'gas_meter_points') List<GasMeterPoint> ? gasMeterPoints}) -
factory
-
Property.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addressLine1 → String?
-
no setterinherited
- addressLine2 → String?
-
no setterinherited
- addressLine3 → String?
-
no setterinherited
-
copyWith
→ $PropertyCopyWith<
Property> -
no setterinherited
- county → String?
-
no setterinherited
-
electricityMeterPoints
→ List<
ElectricityMeterPoint> ? -
no setterinherited
-
gasMeterPoints
→ List<
GasMeterPoint> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
no setterinherited
- moveInDate → DateTime?
-
no setterinherited
- moveOutDate → DateTime?
-
no setterinherited
- postcode → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- town → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited